@@ -29,6 +29,20 @@ class AsyncTestCase:
     def assertTrue(self, *args):
         self.assertEqual(True, *args)
 
+    def assertGreaterThan(self, a, b):
+        try:
+            self.assertTrue(a > b)
+        except AssertionError:
+            raise AssertionError(
+                f"\n\n{beeprint.pp(a, output=False, sort_keys=False, string_break_enable=False)}\nis not greater than \n\n{beeprint.pp(b, output=False, sort_keys=False, string_break_enable=False)}.")
+
+    def assertLessThan(self, a, b):
+        try:
+            self.assertTrue(a < b)
+        except AssertionError:
+            raise AssertionError(
+                f"\n\n{beeprint.pp(a, output=False, sort_keys=False, string_break_enable=False)}\nis not less than \n\n{beeprint.pp(b, output=False, sort_keys=False, string_break_enable=False)}.")
+
 
 def run():
     loop = asyncio.get_event_loop()
@@ -36,6 +50,7 @@ def run():
     start = loop.time()
     error_count = 0
     all_test_method = []
+    error_tracebacks = []
 
     async def subclass_test(AsyncTestCase_subclass):
         await AsyncTestCase_subclass.setUpClass()
@@ -54,7 +69,8 @@ def run():
                         await asyncio.create_task(test_function())
 
             except:
-                logger.error(traceback.format_exc())
+                nonlocal error_tracebacks
+                error_tracebacks.append(traceback.format_exc())
                 nonlocal error_count
                 error_count += 1
             finally:
@@ -83,6 +99,8 @@ def run():
         [await task for task in subclass_test_tasks]
 
     loop.run_until_complete(main())
+    for error_traceback in error_tracebacks:
+        logger.error(error_traceback)
     (logger.warning if not error_count else logger.error)(
         f'Spent seconds: {loop.time() - start}, error count:{error_count}')
 
@@ -111,9 +129,16 @@ if __name__ == '__main__':
         #     self.assertEqual(res, self.b)
         #     self.assertEqual(res, self.a)
 
-        async def test4(self):
+        # async def test4(self):
+        #     res = await asyncio.sleep(2, 1)
+        #     self.assertTrue(res != 0)
+
+        # async def test_great_than(self):
+        #     res = await asyncio.sleep(2, 1)
+        #     self.assertGreaterThan(res, 2)
+        async def test_less_than(self):
             res = await asyncio.sleep(2, 1)
-            self.assertTrue(res != 0)
+            self.assertLessThan(res, 1)
 
         async def tearDown(self) -> None:
             logger.info('tearDown')
